# ZLE (Symbolic Integer-Linear Matrix Toolkit)

[![PyPI - Version](https://img.shields.io/pypi/v/ile-matrix-tools.svg)](https://pypi.org/project/ile-matrix-tools)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ile-matrix-tools.svg)](https://pypi.org/project/ile-matrix-tools)

-----

A Python package to aid in integer-linear-eigenvalue matrix generation and evaluation.

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install zlepy
```

For local development:
```console
pip install -e path/to/zlepy
```

## Testing

All tests:
```
hatch test
```

Specific test file:
```
hatch test tests/test_batch_sizes.py
```
